# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.cluster import VsanVcLifecycleCheckResult
from pyVmomi.vim.cluster import VsanVcLifecycleCheckSpec

from pyVmomi.vim.vsan import ConfigInfoEx
from pyVmomi.vim.vsan import ReconfigSpec
from pyVmomi.vim.vsan import RuntimeStatsHostMap

from pyVmomi.vim.vsan.host import DrsStats

class VsanVcClusterConfigSystem(ManagedObject):
   def ReconfigureEx(self, cluster: ClusterComputeResource, vsanReconfigSpec: ReconfigSpec) -> Task: ...
   def GetConfigInfoEx(self, cluster: ClusterComputeResource) -> ConfigInfoEx: ...
   def RekeyEncryptedCluster(self, encryptedCluster: ClusterComputeResource, deepRekey: Optional[bool], allowReducedRedundancy: Optional[bool]) -> Task: ...
   def GetRuntimeStats(self, cluster: ClusterComputeResource, stats: list[str]) -> list[RuntimeStatsHostMap]: ...
   def QueryClusterDrsStats(self, cluster: ClusterComputeResource, vms: list[VirtualMachine]) -> list[DrsStats]: ...
   def ValidateConfigSpec(self, cluster: ClusterComputeResource, vsanReconfigSpec: ReconfigSpec) -> list[ClusterComputeResource.ValidationResultBase]: ...
   def RunLifecycleCheck(self, cluster: ClusterComputeResource, vsanLifecycleCheckSpec: VsanVcLifecycleCheckSpec) -> VsanVcLifecycleCheckResult: ...
   def GetClaimedCapacity(self, cluster: ClusterComputeResource) -> long: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import replication as replication

from .AlarmStatus import AlarmStatus as AlarmStatus
from .AlarmType import AlarmType as AlarmType
from .BackingConfig import BackingConfig as BackingConfig
from .BackingStoragePool import BackingStoragePool as BackingStoragePool
from .DatastoreBackingPoolMapping import DatastoreBackingPoolMapping as DatastoreBackingPoolMapping
from .DatastorePair import DatastorePair as DatastorePair
from .DrsMigrationCapabilityResult import DrsMigrationCapabilityResult as DrsMigrationCapabilityResult
from .EntityType import EntityType as EntityType
from .FaultDomainProviderMapping import FaultDomainProviderMapping as FaultDomainProviderMapping
from .FcStoragePort import FcStoragePort as FcStoragePort
from .FcoeStoragePort import FcoeStoragePort as FcoeStoragePort
from .FileSystemInfo import FileSystemInfo as FileSystemInfo
from .IscsiStoragePort import IscsiStoragePort as IscsiStoragePort
from .LunHbaAssociation import LunHbaAssociation as LunHbaAssociation
from .NameValuePair import NameValuePair as NameValuePair
from .StorageAlarm import StorageAlarm as StorageAlarm
from .StorageArray import StorageArray as StorageArray
from .StorageCapability import StorageCapability as StorageCapability
from .StorageContainer import StorageContainer as StorageContainer
from .StorageContainerResult import StorageContainerResult as StorageContainerResult
from .StorageContainerSpec import StorageContainerSpec as StorageContainerSpec
from .StorageFileSystem import StorageFileSystem as StorageFileSystem
from .StorageLun import StorageLun as StorageLun
from .StoragePort import StoragePort as StoragePort
from .StorageProcessor import StorageProcessor as StorageProcessor
from .ThinProvisioningStatus import ThinProvisioningStatus as ThinProvisioningStatus



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim import ElementDescription
from pyVmomi.vim import TypeDescription

from pyVmomi.vmodl import DynamicData

class AlarmDescription(DynamicData):
   expr: list[TypeDescription] = []
   stateOperator: list[ElementDescription] = []
   metricOperator: list[ElementDescription] = []
   hostSystemConnectionState: list[ElementDescription] = []
   virtualMachinePowerState: list[ElementDescription] = []
   datastoreConnectionState: list[ElementDescription] = []
   hostSystemPowerState: list[ElementDescription] = []
   virtualMachineGuestHeartbeatStatus: list[ElementDescription] = []
   entityStatus: list[ElementDescription] = []
   action: list[TypeDescription] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import ChoiceOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualSerialPortOption(VirtualDeviceOption):
   class EndPoint(Enum):
      client: ClassVar['EndPoint'] = 'client'
      server: ClassVar['EndPoint'] = 'server'

   class FileBackingOption(VirtualDeviceOption.FileBackingOption):
      pass

   class DeviceBackingOption(VirtualDeviceOption.DeviceBackingOption):
      pass

   class PipeBackingOption(VirtualDeviceOption.PipeBackingOption):
      endpoint: ChoiceOption
      noRxLoss: BoolOption

   class URIBackingOption(VirtualDeviceOption.URIBackingOption):
      pass

   class ThinPrintBackingOption(VirtualDeviceOption.BackingOption):
      pass

   yieldOnPoll: BoolOption



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.pbm.capability import CapabilityMetadata
from pyVmomi.pbm.capability import PropertyInstance

from pyVmomi.pbm.fault import CompatibilityCheckFault

class PropertyMismatchFault(CompatibilityCheckFault):
   capabilityInstanceId: CapabilityMetadata.UniqueId
   requirementPropertyInstance: PropertyInstance



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VasaStorageArray
from pyVmomi.vim import VimVasaProviderInfo

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import FileSystemVolume
from pyVmomi.vim.host import ProtocolEndpoint
from pyVmomi.vim.host import VvolNQN

class VvolVolume(FileSystemVolume):
   class Specification(DynamicData):
      maxSizeInMB: long
      volumeName: str
      vasaProviderInfo: list[VimVasaProviderInfo] = []
      storageArray: list[VasaStorageArray] = []
      uuid: str
      stretched: Optional[bool] = None

   class HostProtocolEndpoint(DynamicData):
      key: HostSystem
      protocolEndpoint: list[ProtocolEndpoint] = []

   class HostVvolNQN(DynamicData):
      host: Optional[HostSystem] = None
      vvolNQN: list[VvolNQN] = []

   scId: str
   hostPE: list[HostProtocolEndpoint] = []
   hostVvolNQN: list[HostVvolNQN] = []
   vasaProviderInfo: list[VimVasaProviderInfo] = []
   storageArray: list[VasaStorageArray] = []
   protocolEndpointType: Optional[str] = None
   vvolNQNFieldsAvailable: Optional[bool] = None
   stretched: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Task

from pyVmomi.vim.cluster import VsanIscsiInitiatorGroup
from pyVmomi.vim.cluster import VsanIscsiLUN
from pyVmomi.vim.cluster import VsanIscsiLUNSpec
from pyVmomi.vim.cluster import VsanIscsiTarget
from pyVmomi.vim.cluster import VsanIscsiTargetSpec
from pyVmomi.vim.cluster import VsanObjectInformation

class VsanIscsiTargetSystem(ManagedObject):
   def QueryIscsiTargetServiceVersion(self) -> str: ...
   def GetHomeObject(self, cluster: ClusterComputeResource) -> VsanObjectInformation: ...
   def GetIscsiTargets(self, cluster: ClusterComputeResource) -> list[VsanIscsiTarget]: ...
   def GetIscsiTarget(self, cluster: ClusterComputeResource, targetAlias: str) -> Optional[VsanIscsiTarget]: ...
   def AddIscsiTarget(self, cluster: ClusterComputeResource, targetSpec: VsanIscsiTargetSpec) -> Optional[Task]: ...
   def EditIscsiTarget(self, cluster: ClusterComputeResource, targetSpec: VsanIscsiTargetSpec) -> Optional[Task]: ...
   def RemoveIscsiTarget(self, cluster: ClusterComputeResource, targetAlias: str) -> Optional[Task]: ...
   def GetIscsiLUNs(self, cluster: ClusterComputeResource, targetAliases: list[str]) -> list[VsanIscsiLUN]: ...
   def GetIscsiLUN(self, cluster: ClusterComputeResource, targetAlias: str, lunId: int) -> Optional[VsanIscsiLUN]: ...
   def AddIscsiLUN(self, cluster: ClusterComputeResource, targetAlias: str, lunSpec: VsanIscsiLUNSpec) -> Optional[Task]: ...
   def EditIscsiLUN(self, cluster: ClusterComputeResource, targetAlias: str, lunSpec: VsanIscsiLUNSpec) -> Optional[Task]: ...
   def RemoveIscsiLUN(self, cluster: ClusterComputeResource, targetAlias: str, lunId: int) -> Optional[Task]: ...
   def AddIscsiInitiatorsToTarget(self, cluster: ClusterComputeResource, targetAlias: str, initiatorNames: list[str]) -> NoReturn: ...
   def RemoveIscsiInitiatorsFromTarget(self, cluster: ClusterComputeResource, targetAlias: str, initiatorNames: list[str]) -> NoReturn: ...
   def GetIscsiInitiatorGroups(self, cluster: ClusterComputeResource) -> list[VsanIscsiInitiatorGroup]: ...
   def GetIscsiInitiatorGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str) -> Optional[VsanIscsiInitiatorGroup]: ...
   def AddIscsiInitiatorGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str) -> NoReturn: ...
   def RemoveIscsiInitiatorGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str) -> NoReturn: ...
   def AddIscsiInitiatorsToGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str, initiatorNames: list[str]) -> NoReturn: ...
   def RemoveIscsiInitiatorsFromGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str, initiatorNames: list[str]) -> NoReturn: ...
   def AddIscsiTargetToGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str, targetAlias: str) -> NoReturn: ...
   def RemoveIscsiTargetFromGroup(self, cluster: ClusterComputeResource, initiatorGroupName: str, targetAlias: str) -> NoReturn: ...
   def RemediateIscsiLunsRuntimeStatus(self, cluster: ClusterComputeResource) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import auth as auth
from . import fault as fault
from . import provider as provider
from . import storage as storage

from .AboutInfo import AboutInfo as AboutInfo
from .EntityReference import EntityReference as EntityReference
from .FaultDomainFilter import FaultDomainFilter as FaultDomainFilter
from .ReplicationGroupFilter import ReplicationGroupFilter as ReplicationGroupFilter
from .ServiceInstance import ServiceInstance as ServiceInstance
from .StorageManager import StorageManager as StorageManager
from .Task import Task as Task
from .TaskInfo import TaskInfo as TaskInfo



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .ComplianceManager import ComplianceManager as ComplianceManager
from .ComplianceResult import ComplianceResult as ComplianceResult
from .FetchEntityHealthStatusSpec import FetchEntityHealthStatusSpec as FetchEntityHealthStatusSpec
from .OperationalStatus import OperationalStatus as OperationalStatus
from .PolicyStatus import PolicyStatus as PolicyStatus
from .RollupComplianceResult import RollupComplianceResult as RollupComplianceResult



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class IpStackInfo(DynamicData):
   class EntryType(Enum):
      other: ClassVar['EntryType'] = 'other'
      invalid: ClassVar['EntryType'] = 'invalid'
      dynamic: ClassVar['EntryType'] = 'dynamic'
      manual: ClassVar['EntryType'] = 'manual'

   class Preference(Enum):
      reserved: ClassVar['Preference'] = 'reserved'
      low: ClassVar['Preference'] = 'low'
      medium: ClassVar['Preference'] = 'medium'
      high: ClassVar['Preference'] = 'high'

   class NetToMedia(DynamicData):
      ipAddress: str
      physicalAddress: str
      device: str
      type: str

   class DefaultRouter(DynamicData):
      ipAddress: str
      device: str
      lifetime: datetime
      preference: str

   neighbor: list[NetToMedia] = []
   defaultRouter: list[DefaultRouter] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import PhysicalNic

class RdmaDevice(DynamicData):
   class Backing(DynamicData):
      pass

   class PnicBacking(Backing):
      pairedUplink: PhysicalNic

   class ConnectionState(Enum):
      unknown: ClassVar['ConnectionState'] = 'unknown'
      down: ClassVar['ConnectionState'] = 'down'
      init: ClassVar['ConnectionState'] = 'init'
      armed: ClassVar['ConnectionState'] = 'armed'
      active: ClassVar['ConnectionState'] = 'active'
      activeDefer: ClassVar['ConnectionState'] = 'activeDefer'

   class ConnectionInfo(DynamicData):
      state: str
      mtu: int
      speedInMbps: int

   class Capability(DynamicData):
      roceV1Capable: bool
      roceV2Capable: bool
      iWarpCapable: bool

   key: str
   device: str
   driver: Optional[str] = None
   description: Optional[str] = None
   backing: Optional[Backing] = None
   connectionInfo: ConnectionInfo
   capability: Capability



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import double
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import SharesInfo
from pyVmomi.vim import SharesOption
from pyVmomi.vim import StoragePod
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.cluster import ActionHistory
from pyVmomi.vim.cluster import DrsFaults
from pyVmomi.vim.cluster import Recommendation

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import IntOption
from pyVmomi.vim.option import LongOption

from pyVmomi.vim.storageDrs import ConfigInfo
from pyVmomi.vim.storageDrs import ConfigSpec
from pyVmomi.vim.storageDrs import StoragePlacementResult
from pyVmomi.vim.storageDrs import StoragePlacementSpec

class StorageResourceManager(ManagedObject):
   class IOAllocationInfo(DynamicData):
      limit: Optional[long] = None
      shares: Optional[SharesInfo] = None
      reservation: Optional[int] = None

   class IOAllocationOption(DynamicData):
      limitOption: LongOption
      sharesOption: SharesOption

   class CongestionThresholdMode(Enum):
      automatic: ClassVar['CongestionThresholdMode'] = 'automatic'
      manual: ClassVar['CongestionThresholdMode'] = 'manual'

   class IORMConfigInfo(DynamicData):
      enabled: bool
      congestionThresholdMode: str
      congestionThreshold: int
      percentOfPeakThroughput: Optional[int] = None
      statsCollectionEnabled: bool
      reservationEnabled: bool
      statsAggregationDisabled: Optional[bool] = None
      reservableIopsThreshold: Optional[int] = None

   class IORMConfigSpec(DynamicData):
      enabled: Optional[bool] = None
      congestionThresholdMode: Optional[str] = None
      congestionThreshold: Optional[int] = None
      percentOfPeakThroughput: Optional[int] = None
      statsCollectionEnabled: Optional[bool] = None
      reservationEnabled: Optional[bool] = None
      statsAggregationDisabled: Optional[bool] = None
      reservableIopsThreshold: Optional[int] = None

   class IORMConfigOption(DynamicData):
      enabledOption: BoolOption
      congestionThresholdOption: IntOption
      statsCollectionEnabledOption: BoolOption
      reservationEnabledOption: BoolOption

   class StoragePerformanceSummary(DynamicData):
      interval: int
      percentile: list[int] = []
      datastoreReadLatency: list[double] = []
      datastoreWriteLatency: list[double] = []
      datastoreVmLatency: list[double] = []
      datastoreReadIops: list[double] = []
      datastoreWriteIops: list[double] = []
      siocActivityDuration: int

   class PodStorageDrsEntry(DynamicData):
      storageDrsConfig: ConfigInfo
      recommendation: list[Recommendation] = []
      drsFault: list[DrsFaults] = []
      actionHistory: list[ActionHistory] = []

   class StorageProfileStatistics(DynamicData):
      profileId: str
      totalSpaceMB: long
      usedSpaceMB: long

   def ConfigureDatastoreIORM(self, datastore: Datastore, spec: IORMConfigSpec) -> Task: ...
   def QueryIORMConfigOption(self, host: HostSystem) -> IORMConfigOption: ...
   def QueryDatastorePerformanceSummary(self, datastore: Datastore) -> list[StoragePerformanceSummary]: ...
   def ApplyRecommendationToPod(self, pod: StoragePod, key: str) -> Task: ...
   def ApplyRecommendation(self, key: list[str]) -> Task: ...
   def CancelRecommendation(self, key: list[str]) -> NoReturn: ...
   def RefreshRecommendation(self, pod: StoragePod) -> NoReturn: ...
   def RefreshRecommendationsForPod(self, pod: StoragePod) -> Task: ...
   def ConfigureStorageDrsForPod(self, pod: StoragePod, spec: ConfigSpec, modify: bool) -> Task: ...
   def ValidateStoragePodConfig(self, pod: StoragePod, spec: ConfigSpec) -> Optional[MethodFault]: ...
   def RecommendDatastores(self, storageSpec: StoragePlacementSpec) -> StoragePlacementResult: ...



# Copyright (c) 2006-2024 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import DataObject

from pyVmomi.vmodl import DynamicProperty

class DynamicData(DataObject):
   dynamicType: Optional[str] = None
   dynamicProperty: list[DynamicProperty] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ExtensibleManagedObject

from pyVmomi.vim.host import FirewallInfo
from pyVmomi.vim.host import Ruleset

class FirewallSystem(ExtensibleManagedObject):
   class ServiceName(Enum):
      vpxa: ClassVar['ServiceName'] = 'vpxa'

   class RuleSetId(Enum):
      faultTolerance: ClassVar['RuleSetId'] = 'faultTolerance'
      fdm: ClassVar['RuleSetId'] = 'fdm'
      updateManager: ClassVar['RuleSetId'] = 'updateManager'
      vpxHeartbeats: ClassVar['RuleSetId'] = 'vpxHeartbeats'

   @property
   def firewallInfo(self) -> Optional[FirewallInfo]: ...

   def UpdateDefaultPolicy(self, defaultPolicy: FirewallInfo.DefaultPolicy) -> NoReturn: ...
   def EnableRuleset(self, id: str) -> NoReturn: ...
   def DisableRuleset(self, id: str) -> NoReturn: ...
   def UpdateRuleset(self, id: str, spec: Ruleset.RulesetSpec) -> NoReturn: ...
   def Refresh(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import ResourceCheckComponentResult
from pyVmomi.vim.vsan import ResourceCheckResult
from pyVmomi.vim.vsan import ResourceCheckTaskDetails

class ResourceCheckStatus(DynamicData):
   status: str
   result: Optional[ResourceCheckResult] = None
   task: Optional[ResourceCheckTaskDetails] = None
   parentTask: Optional[ResourceCheckTaskDetails] = None
   componentResults: list[ResourceCheckComponentResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DiskPartitionInfo
from pyVmomi.vim.host import FileSystemVolume
from pyVmomi.vim.host import ScsiDisk

class VffsVolume(FileSystemVolume):
   class Specification(DynamicData):
      devicePath: str
      partition: Optional[DiskPartitionInfo.Specification] = None
      majorVersion: int
      volumeName: str

   majorVersion: int
   version: str
   uuid: str
   extent: list[ScsiDisk.Partition] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.option import ChoiceOption

from pyVmomi.vim.vm.device import VirtualVmxnet3Option

class VirtualVmxnet3VrdmaOption(VirtualVmxnet3Option):
   class DeviceProtocols(Enum):
      rocev1: ClassVar['DeviceProtocols'] = 'rocev1'
      rocev2: ClassVar['DeviceProtocols'] = 'rocev2'

   deviceProtocol: Optional[ChoiceOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import SDDCBase

from pyVmomi.vim.cluster import VsanDiskMappingsConfigSpec
from pyVmomi.vim.cluster import VsanFaultDomainsConfigSpec
from pyVmomi.vim.cluster import VsanIscsiTargetServiceSpec
from pyVmomi.vim.cluster import VsanPerfsvcConfig

from pyVmomi.vim.vsan import DataEfficiencyConfig
from pyVmomi.vim.vsan import DataEncryptionConfig
from pyVmomi.vim.vsan import DataInTransitEncryptionConfig
from pyVmomi.vim.vsan import DatastoreConfig
from pyVmomi.vim.vsan import FileServiceConfig
from pyVmomi.vim.vsan import MetricsConfig
from pyVmomi.vim.vsan import RdmaConfig
from pyVmomi.vim.vsan import ResyncIopsInfo
from pyVmomi.vim.vsan import SnapServiceConfig
from pyVmomi.vim.vsan import VcRemoteVsanServerClusterConfig
from pyVmomi.vim.vsan import VsanDeconvergedNetConfig
from pyVmomi.vim.vsan import VsanEsaConfig
from pyVmomi.vim.vsan import VsanExtendedConfig
from pyVmomi.vim.vsan import VsanHealthConfigSpec
from pyVmomi.vim.vsan import VsanUnmapConfig
from pyVmomi.vim.vsan import VsanVumConfig
from pyVmomi.vim.vsan import XVCDatastoreConfig

from pyVmomi.vim.vsan.cluster import ConfigInfo

class ReconfigSpec(SDDCBase):
   vsanClusterConfig: Optional[ConfigInfo] = None
   dataEfficiencyConfig: Optional[DataEfficiencyConfig] = None
   diskMappingSpec: Optional[VsanDiskMappingsConfigSpec] = None
   faultDomainsSpec: Optional[VsanFaultDomainsConfigSpec] = None
   modify: bool
   allowReducedRedundancy: Optional[bool] = None
   resyncIopsLimitConfig: Optional[ResyncIopsInfo] = None
   iscsiSpec: Optional[VsanIscsiTargetServiceSpec] = None
   dataEncryptionConfig: Optional[DataEncryptionConfig] = None
   extendedConfig: Optional[VsanExtendedConfig] = None
   datastoreConfig: Optional[DatastoreConfig] = None
   perfsvcConfig: Optional[VsanPerfsvcConfig] = None
   unmapConfig: Optional[VsanUnmapConfig] = None
   vumConfig: Optional[VsanVumConfig] = None
   metricsConfig: Optional[MetricsConfig] = None
   fileServiceConfig: Optional[FileServiceConfig] = None
   rdmaConfig: Optional[RdmaConfig] = None
   dataInTransitEncryptionConfig: Optional[DataInTransitEncryptionConfig] = None
   mode: Optional[str] = None
   vsanHealthConfig: Optional[VsanHealthConfigSpec] = None
   vsanEsaConfig: Optional[VsanEsaConfig] = None
   xvcDatastoreConfig: Optional[XVCDatastoreConfig] = None
   serverClusterConfig: Optional[VcRemoteVsanServerClusterConfig] = None
   snapServiceConfig: Optional[SnapServiceConfig] = None
   deconvergedNetConfig: Optional[VsanDeconvergedNetConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class DiskDimensions(DynamicData):
   class Chs(DynamicData):
      cylinder: long
      head: int
      sector: int

   class Lba(DynamicData):
      blockSize: int
      block: long



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import UnresolvedVmfsExtent

class UnresolvedVmfsVolume(DynamicData):
   class ResolveStatus(DynamicData):
      resolvable: bool
      incompleteExtents: Optional[bool] = None
      multipleCopies: Optional[bool] = None

   extent: list[UnresolvedVmfsExtent] = []
   vmfsLabel: str
   vmfsUuid: str
   totalBlocks: int
   resolveStatus: ResolveStatus



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Task

from pyVmomi.vim.cluster import ClusterPowerContext
from pyVmomi.vim.cluster import PerformClusterPowerActionSpec

class VsanClusterPowerSystem(ManagedObject):
   def PerformClusterPowerAction(self, cluster: ComputeResource, spec: PerformClusterPowerActionSpec) -> Task: ...
   def QueryClusterPowerContext(self, cluster: ComputeResource) -> ClusterPowerContext: ...
   def UpdateClusterPowerStatus(self, cluster: ComputeResource, status: str) -> bool: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn

from pyVmomi.vim import ExtensibleManagedObject

from pyVmomi.vim.scheduler import ScheduledTaskInfo
from pyVmomi.vim.scheduler import ScheduledTaskSpec

class ScheduledTask(ExtensibleManagedObject):
   @property
   def info(self) -> ScheduledTaskInfo: ...

   def Remove(self) -> NoReturn: ...
   def Reconfigure(self, spec: ScheduledTaskSpec) -> NoReturn: ...
   def Run(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

class LocalizationManager(ManagedObject):
   class MessageCatalog(DynamicData):
      moduleName: str
      catalogName: str
      locale: str
      catalogUri: str
      lastModified: Optional[datetime] = None
      md5sum: Optional[str] = None
      version: Optional[str] = None

   @property
   def catalog(self) -> list[MessageCatalog]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Datastore
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.cluster import Action

from pyVmomi.vim.vm import RelocateSpec

class StoragePlacementAction(Action):
   vm: Optional[VirtualMachine] = None
   relocateSpec: RelocateSpec
   destination: Datastore
   spaceUtilBefore: Optional[float] = None
   spaceDemandBefore: Optional[float] = None
   spaceUtilAfter: Optional[float] = None
   spaceDemandAfter: Optional[float] = None
   ioLatencyBefore: Optional[float] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.fault import DvsFault

class ImportOperationBulkFault(DvsFault):
   class FaultOnImport(DynamicData):
      entityType: Optional[str] = None
      key: Optional[str] = None
      fault: MethodFault

   importFaults: list[FaultOnImport] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class NetBIOSConfigInfo(DynamicData):
   class Mode(Enum):
      unknown: ClassVar['Mode'] = 'unknown'
      enabled: ClassVar['Mode'] = 'enabled'
      disabled: ClassVar['Mode'] = 'disabled'
      enabledViaDHCP: ClassVar['Mode'] = 'enabledViaDHCP'

   mode: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import QualifiedName
from pyVmomi.vim.host import SystemIdentificationInfo

class SystemInfo(DynamicData):
   vendor: str
   model: str
   family: Optional[str] = None
   uuid: str
   otherIdentifyingInfo: list[SystemIdentificationInfo] = []
   serialNumber: Optional[str] = None
   qualifiedName: list[QualifiedName] = []
   vvolHostNQN: Optional[QualifiedName] = None
   vvolHostId: Optional[str] = None
   bootCommandLine: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task

from pyVmomi.vim.host import MaintenanceSpec
from pyVmomi.vim.host import ScsiDisk

from pyVmomi.vim.vsan.host import ClusterStatus
from pyVmomi.vim.vsan.host import ConfigInfo
from pyVmomi.vim.vsan.host import DiskMapping
from pyVmomi.vim.vsan.host import DiskResult

class VsanSystem(ManagedObject):
   @property
   def config(self) -> ConfigInfo: ...

   def QueryDisksForVsan(self, canonicalName: list[str]) -> list[DiskResult]: ...
   def AddDisks(self, disk: list[ScsiDisk]) -> Task: ...
   def InitializeDisks(self, mapping: list[DiskMapping]) -> Task: ...
   def RemoveDisk(self, disk: list[ScsiDisk], maintenanceSpec: Optional[MaintenanceSpec], timeout: Optional[int]) -> Task: ...
   def RemoveDiskMapping(self, mapping: list[DiskMapping], maintenanceSpec: Optional[MaintenanceSpec], timeout: Optional[int]) -> Task: ...
   def UnmountDiskMapping(self, mapping: list[DiskMapping]) -> Task: ...
   def Update(self, config: ConfigInfo) -> Task: ...
   def QueryHostStatus(self) -> ClusterStatus: ...
   def EvacuateNode(self, maintenanceSpec: MaintenanceSpec, timeout: int) -> Task: ...
   def RecommissionNode(self) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import IpConfig

class PtpConfig(DynamicData):
   class DeviceType(Enum):
      none: ClassVar['DeviceType'] = 'none'
      virtualNic: ClassVar['DeviceType'] = 'virtualNic'
      pciPassthruNic: ClassVar['DeviceType'] = 'pciPassthruNic'

   class PtpPort(DynamicData):
      index: int
      deviceType: Optional[str] = None
      device: Optional[str] = None
      ipConfig: Optional[IpConfig] = None

   domain: Optional[int] = None
   port: list[PtpPort] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

class CryptoConfigInfo(DynamicData):
   class CryptoMode(Enum):
      onDemand: ClassVar['CryptoMode'] = 'onDemand'
      forceEnable: ClassVar['CryptoMode'] = 'forceEnable'

   cryptoMode: Optional[str] = None
   policy: Optional[ClusterComputeResource.CryptoModePolicy] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.dvs import DistributedVirtualPort
from pyVmomi.vim.dvs import EntityBackup
from pyVmomi.vim.dvs import KeyedOpaqueBlob

class DistributedVirtualPortgroup(Network):
   class PortgroupType(Enum):
      earlyBinding: ClassVar['PortgroupType'] = 'earlyBinding'
      lateBinding: ClassVar['PortgroupType'] = 'lateBinding'
      ephemeral: ClassVar['PortgroupType'] = 'ephemeral'

   class BackingType(Enum):
      standard: ClassVar['BackingType'] = 'standard'
      nsx: ClassVar['BackingType'] = 'nsx'

   class PortgroupPolicy(DynamicData):
      blockOverrideAllowed: bool
      shapingOverrideAllowed: bool
      vendorConfigOverrideAllowed: bool
      livePortMovingAllowed: bool
      portConfigResetAtDisconnect: bool
      networkResourcePoolOverrideAllowed: Optional[bool] = None
      trafficFilterOverrideAllowed: Optional[bool] = None

   class MetaTagName(Enum):
      dvsName: ClassVar['MetaTagName'] = 'dvsName'
      portgroupName: ClassVar['MetaTagName'] = 'portgroupName'
      portIndex: ClassVar['MetaTagName'] = 'portIndex'

   class ConfigSpec(DynamicData):
      configVersion: Optional[str] = None
      name: Optional[str] = None
      numPorts: Optional[int] = None
      portNameFormat: Optional[str] = None
      defaultPortConfig: Optional[DistributedVirtualPort.Setting] = None
      description: Optional[str] = None
      type: Optional[str] = None
      backingType: Optional[str] = None
      scope: list[ManagedEntity] = []
      policy: Optional[PortgroupPolicy] = None
      vendorSpecificConfig: list[KeyedOpaqueBlob] = []
      autoExpand: Optional[bool] = None
      vmVnicNetworkResourcePoolKey: Optional[str] = None
      transportZoneUuid: Optional[str] = None
      transportZoneName: Optional[str] = None
      logicalSwitchUuid: Optional[str] = None
      segmentId: Optional[str] = None
      subnetId: Optional[str] = None

   class ConfigInfo(DynamicData):
      key: str
      name: str
      numPorts: int
      distributedVirtualSwitch: Optional[DistributedVirtualSwitch] = None
      defaultPortConfig: Optional[DistributedVirtualPort.Setting] = None
      description: Optional[str] = None
      type: str
      backingType: Optional[str] = None
      policy: PortgroupPolicy
      portNameFormat: Optional[str] = None
      scope: list[ManagedEntity] = []
      vendorSpecificConfig: list[KeyedOpaqueBlob] = []
      configVersion: Optional[str] = None
      autoExpand: Optional[bool] = None
      vmVnicNetworkResourcePoolKey: Optional[str] = None
      uplink: Optional[bool] = None
      transportZoneUuid: Optional[str] = None
      transportZoneName: Optional[str] = None
      logicalSwitchUuid: Optional[str] = None
      segmentId: Optional[str] = None
      subnetId: Optional[str] = None

   class Problem(DynamicData):
      logicalSwitchUuid: str
      fault: MethodFault

   class NsxPortgroupOperationResult(DynamicData):
      portgroups: list[DistributedVirtualPortgroup] = []
      problems: list[Problem] = []

   @property
   def key(self) -> str: ...
   @property
   def config(self) -> ConfigInfo: ...
   @property
   def portKeys(self) -> list[str]: ...

   def Reconfigure(self, spec: ConfigSpec) -> Task: ...
   def Rollback(self, entityBackup: Optional[EntityBackup.Config]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class Capability(DynamicData):
   snapshotOperationsSupported: bool
   multipleSnapshotsSupported: bool
   snapshotConfigSupported: bool
   poweredOffSnapshotsSupported: bool
   memorySnapshotsSupported: bool
   revertToSnapshotSupported: bool
   quiescedSnapshotsSupported: bool
   disableSnapshotsSupported: bool
   lockSnapshotsSupported: bool
   consolePreferencesSupported: bool
   cpuFeatureMaskSupported: bool
   s1AcpiManagementSupported: bool
   settingScreenResolutionSupported: bool
   toolsAutoUpdateSupported: bool
   vmNpivWwnSupported: bool
   npivWwnOnNonRdmVmSupported: bool
   vmNpivWwnDisableSupported: bool
   vmNpivWwnUpdateSupported: bool
   swapPlacementSupported: bool
   toolsSyncTimeSupported: bool
   virtualMmuUsageSupported: bool
   diskSharesSupported: bool
   bootOptionsSupported: bool
   bootRetryOptionsSupported: bool
   settingVideoRamSizeSupported: bool
   settingDisplayTopologySupported: bool
   recordReplaySupported: bool
   changeTrackingSupported: bool
   multipleCoresPerSocketSupported: bool
   hostBasedReplicationSupported: bool
   guestAutoLockSupported: bool
   memoryReservationLockSupported: bool
   featureRequirementSupported: bool
   poweredOnMonitorTypeChangeSupported: bool
   seSparseDiskSupported: bool
   nestedHVSupported: bool
   vPMCSupported: bool
   secureBootSupported: Optional[bool] = None
   perVmEvcSupported: Optional[bool] = None
   virtualMmuUsageIgnored: Optional[bool] = None
   virtualExecUsageIgnored: Optional[bool] = None
   diskOnlySnapshotOnSuspendedVMSupported: Optional[bool] = None
   suspendToMemorySupported: Optional[bool] = None
   toolsSyncTimeAllowSupported: Optional[bool] = None
   sevSupported: Optional[bool] = None
   pmemFailoverSupported: Optional[bool] = None
   requireSgxAttestationSupported: Optional[bool] = None
   changeModeDisksSupported: Optional[bool] = None
   vendorDeviceGroupSupported: Optional[bool] = None
   sevSnpSupported: Optional[bool] = None
   tdxSupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import binary
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.vm.guest import GuestAuthentication

class WindowsRegistryManager(ManagedObject):
   class RegistryKeyName(DynamicData):
      class RegistryKeyWowBitness(Enum):
         WOWNative: ClassVar['RegistryKeyWowBitness'] = 'WOWNative'
         WOW32: ClassVar['RegistryKeyWowBitness'] = 'WOW32'
         WOW64: ClassVar['RegistryKeyWowBitness'] = 'WOW64'

      registryPath: str
      wowBitness: str

   class RegistryKey(DynamicData):
      keyName: RegistryKeyName
      classType: str
      lastWritten: datetime

   class RegistryKeyRecord(DynamicData):
      key: RegistryKey
      fault: Optional[MethodFault] = None

   class RegistryValueName(DynamicData):
      keyName: RegistryKeyName
      name: str

   class RegistryValueData(DynamicData):
      pass

   class RegistryValueDword(RegistryValueData):
      value: int

   class RegistryValueQword(RegistryValueData):
      value: long

   class RegistryValueString(RegistryValueData):
      value: Optional[str] = None

   class RegistryValueExpandString(RegistryValueData):
      value: Optional[str] = None

   class RegistryValueMultiString(RegistryValueData):
      value: list[str] = []

   class RegistryValueBinary(RegistryValueData):
      value: Optional[binary] = None

   class RegistryValue(DynamicData):
      name: RegistryValueName
      data: RegistryValueData

   def CreateRegistryKey(self, vm: VirtualMachine, auth: GuestAuthentication, keyName: RegistryKeyName, isVolatile: bool, classType: Optional[str]) -> NoReturn: ...
   def ListRegistryKeys(self, vm: VirtualMachine, auth: GuestAuthentication, keyName: RegistryKeyName, recursive: bool, matchPattern: Optional[str]) -> list[RegistryKeyRecord]: ...
   def DeleteRegistryKey(self, vm: VirtualMachine, auth: GuestAuthentication, keyName: RegistryKeyName, recursive: bool) -> NoReturn: ...
   def SetRegistryValue(self, vm: VirtualMachine, auth: GuestAuthentication, value: RegistryValue) -> NoReturn: ...
   def ListRegistryValues(self, vm: VirtualMachine, auth: GuestAuthentication, keyName: RegistryKeyName, expandStrings: bool, matchPattern: Optional[str]) -> list[RegistryValue]: ...
   def DeleteRegistryValue(self, vm: VirtualMachine, auth: GuestAuthentication, valueName: RegistryValueName) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.pbm import ServerObjectRef

from pyVmomi.pbm.compliance import ComplianceResult
from pyVmomi.pbm.compliance import RollupComplianceResult

from pyVmomi.pbm.profile import ProfileId

class ComplianceManager(ManagedObject):
   def CheckCompliance(self, entities: list[ServerObjectRef], profile: Optional[ProfileId]) -> list[ComplianceResult]: ...
   def FetchComplianceResult(self, entities: list[ServerObjectRef], profile: Optional[ProfileId]) -> list[ComplianceResult]: ...
   def CheckRollupCompliance(self, entity: list[ServerObjectRef]) -> list[RollupComplianceResult]: ...
   def FetchRollupComplianceResult(self, entity: list[ServerObjectRef]) -> list[RollupComplianceResult]: ...
   def QueryByRollupComplianceStatus(self, status: str) -> list[ServerObjectRef]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.storage.replication import GroupInfo
from pyVmomi.sms.storage.replication import TargetGroupMemberInfo

from pyVmomi.vim.vm.replication import ReplicationGroupId

class TargetGroupInfo(GroupInfo):
   class TargetToSourceInfo(DynamicData):
      sourceGroupId: ReplicationGroupId
      replicationAgreementDescription: Optional[str] = None

   sourceInfo: TargetToSourceInfo
   state: str
   devices: list[TargetGroupMemberInfo] = []
   isPromoteCapable: Optional[bool] = None
   name: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.eam import Agency
from pyVmomi.eam import EamObject

from pyVmomi.eam.issue import Issue

class EsxAgentManager(EamObject):
   class MaintenanceModePolicy(Enum):
      singleHost: ClassVar['MaintenanceModePolicy'] = 'singleHost'
      multipleHosts: ClassVar['MaintenanceModePolicy'] = 'multipleHosts'

   @property
   def agency(self) -> list[Agency]: ...
   @property
   def issue(self) -> list[Issue]: ...

   def QueryAgency(self) -> list[Agency]: ...
   def CreateAgency(self, agencyConfigInfo: Agency.ConfigInfo, initialGoalState: str) -> Agency: ...
   def ScanForUnknownAgentVm(self) -> NoReturn: ...
   def SetMaintenanceModePolicy(self, policy: str) -> NoReturn: ...
   def GetMaintenanceModePolicy(self) -> str: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class FileAccess(DynamicData):
   class Modes(DynamicData):
      browse: Optional[str] = None
      read: str
      modify: str
      use: str
      admin: Optional[str] = None
      full: str

   who: str
   what: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class Fru(DynamicData):
   class FruType(Enum):
      undefined: ClassVar['FruType'] = 'undefined'
      board: ClassVar['FruType'] = 'board'
      product: ClassVar['FruType'] = 'product'

   type: str
   partName: str
   partNumber: str
   manufacturer: str
   serialNumber: Optional[str] = None
   mfgTimeStamp: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long
from pyVmomi.VmomiSupport import short

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import CpuIdInfo

class CpuPackage(DynamicData):
   class Vendor(Enum):
      unknown: ClassVar['Vendor'] = 'unknown'
      intel: ClassVar['Vendor'] = 'intel'
      amd: ClassVar['Vendor'] = 'amd'
      hygon: ClassVar['Vendor'] = 'hygon'
      arm: ClassVar['Vendor'] = 'arm'

   index: short
   vendor: str
   hz: long
   busHz: long
   description: str
   threadId: list[short] = []
   cpuFeature: list[CpuIdInfo] = []
   family: Optional[short] = None
   model: Optional[short] = None
   stepping: Optional[short] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim.vm.device import VirtualDevice

class VirtualVideoCard(VirtualDevice):
   class Use3dRenderer(Enum):
      automatic: ClassVar['Use3dRenderer'] = 'automatic'
      software: ClassVar['Use3dRenderer'] = 'software'
      hardware: ClassVar['Use3dRenderer'] = 'hardware'

   videoRamSizeInKB: Optional[long] = None
   numDisplays: Optional[int] = None
   useAutoDetect: Optional[bool] = None
   enable3DSupport: Optional[bool] = None
   use3dRenderer: Optional[str] = None
   graphicsMemorySizeInKB: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.sms.provider import ProviderInfo

class VasaProviderInfo(ProviderInfo):
   class CertificateStatus(Enum):
      valid: ClassVar['CertificateStatus'] = 'valid'
      expirySoftLimitReached: ClassVar['CertificateStatus'] = 'expirySoftLimitReached'
      expiryHardLimitReached: ClassVar['CertificateStatus'] = 'expiryHardLimitReached'
      expired: ClassVar['CertificateStatus'] = 'expired'
      invalid: ClassVar['CertificateStatus'] = 'invalid'

   class RelatedStorageArray(DynamicData):
      arrayId: str
      active: bool
      manageable: bool
      priority: int

   class SupportedVendorModelMapping(DynamicData):
      vendorId: Optional[str] = None
      modelId: Optional[str] = None

   class VasaProviderStatus(Enum):
      online: ClassVar['VasaProviderStatus'] = 'online'
      offline: ClassVar['VasaProviderStatus'] = 'offline'
      syncError: ClassVar['VasaProviderStatus'] = 'syncError'
      unknown: ClassVar['VasaProviderStatus'] = 'unknown'
      connected: ClassVar['VasaProviderStatus'] = 'connected'
      disconnected: ClassVar['VasaProviderStatus'] = 'disconnected'

   class VasaProviderProfile(Enum):
      blockDevice: ClassVar['VasaProviderProfile'] = 'blockDevice'
      fileSystem: ClassVar['VasaProviderProfile'] = 'fileSystem'
      capability: ClassVar['VasaProviderProfile'] = 'capability'

   class ProviderProfile(Enum):
      ProfileBasedManagement: ClassVar['ProviderProfile'] = 'ProfileBasedManagement'
      Replication: ClassVar['ProviderProfile'] = 'Replication'

   class Type(Enum):
      PERSISTENCE: ClassVar['Type'] = 'PERSISTENCE'
      DATASERVICE: ClassVar['Type'] = 'DATASERVICE'
      UNKNOWN: ClassVar['Type'] = 'UNKNOWN'

   class Category(Enum):
      internal: ClassVar['Category'] = 'internal'
      external: ClassVar['Category'] = 'external'

   url: str
   certificate: Optional[str] = None
   status: Optional[str] = None
   statusFault: Optional[MethodFault] = None
   vasaVersion: Optional[str] = None
   namespace: Optional[str] = None
   lastSyncTime: Optional[str] = None
   supportedVendorModelMapping: list[SupportedVendorModelMapping] = []
   supportedProfile: list[str] = []
   supportedProviderProfile: list[str] = []
   relatedStorageArray: list[RelatedStorageArray] = []
   providerId: Optional[str] = None
   certificateExpiryDate: Optional[str] = None
   certificateStatus: Optional[str] = None
   serviceLocation: Optional[str] = None
   needsExplicitActivation: Optional[bool] = None
   maxBatchSize: Optional[long] = None
   retainVasaProviderCertificate: Optional[bool] = None
   arrayIndependentProvider: Optional[bool] = None
   type: Optional[str] = None
   category: Optional[str] = None
   priority: Optional[int] = None
   failoverGroupId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity

from pyVmomi.vim.fault import VmFaultToleranceIssue

class VmFaultToleranceConfigIssue(VmFaultToleranceIssue):
   class ReasonForIssue(Enum):
      haNotEnabled: ClassVar['ReasonForIssue'] = 'haNotEnabled'
      moreThanOneSecondary: ClassVar['ReasonForIssue'] = 'moreThanOneSecondary'
      recordReplayNotSupported: ClassVar['ReasonForIssue'] = 'recordReplayNotSupported'
      replayNotSupported: ClassVar['ReasonForIssue'] = 'replayNotSupported'
      templateVm: ClassVar['ReasonForIssue'] = 'templateVm'
      multipleVCPU: ClassVar['ReasonForIssue'] = 'multipleVCPU'
      hostInactive: ClassVar['ReasonForIssue'] = 'hostInactive'
      ftUnsupportedHardware: ClassVar['ReasonForIssue'] = 'ftUnsupportedHardware'
      ftUnsupportedProduct: ClassVar['ReasonForIssue'] = 'ftUnsupportedProduct'
      missingVMotionNic: ClassVar['ReasonForIssue'] = 'missingVMotionNic'
      missingFTLoggingNic: ClassVar['ReasonForIssue'] = 'missingFTLoggingNic'
      thinDisk: ClassVar['ReasonForIssue'] = 'thinDisk'
      verifySSLCertificateFlagNotSet: ClassVar['ReasonForIssue'] = 'verifySSLCertificateFlagNotSet'
      hasSnapshots: ClassVar['ReasonForIssue'] = 'hasSnapshots'
      noConfig: ClassVar['ReasonForIssue'] = 'noConfig'
      ftSecondaryVm: ClassVar['ReasonForIssue'] = 'ftSecondaryVm'
      hasLocalDisk: ClassVar['ReasonForIssue'] = 'hasLocalDisk'
      esxAgentVm: ClassVar['ReasonForIssue'] = 'esxAgentVm'
      video3dEnabled: ClassVar['ReasonForIssue'] = 'video3dEnabled'
      hasUnsupportedDisk: ClassVar['ReasonForIssue'] = 'hasUnsupportedDisk'
      insufficientBandwidth: ClassVar['ReasonForIssue'] = 'insufficientBandwidth'
      hasNestedHVConfiguration: ClassVar['ReasonForIssue'] = 'hasNestedHVConfiguration'
      hasVFlashConfiguration: ClassVar['ReasonForIssue'] = 'hasVFlashConfiguration'
      unsupportedProduct: ClassVar['ReasonForIssue'] = 'unsupportedProduct'
      cpuHvUnsupported: ClassVar['ReasonForIssue'] = 'cpuHvUnsupported'
      cpuHwmmuUnsupported: ClassVar['ReasonForIssue'] = 'cpuHwmmuUnsupported'
      cpuHvDisabled: ClassVar['ReasonForIssue'] = 'cpuHvDisabled'
      hasEFIFirmware: ClassVar['ReasonForIssue'] = 'hasEFIFirmware'
      tooManyVCPUs: ClassVar['ReasonForIssue'] = 'tooManyVCPUs'
      tooMuchMemory: ClassVar['ReasonForIssue'] = 'tooMuchMemory'
      vMotionNotLicensed: ClassVar['ReasonForIssue'] = 'vMotionNotLicensed'
      ftNotLicensed: ClassVar['ReasonForIssue'] = 'ftNotLicensed'
      haAgentIssue: ClassVar['ReasonForIssue'] = 'haAgentIssue'
      unsupportedSPBM: ClassVar['ReasonForIssue'] = 'unsupportedSPBM'
      hasLinkedCloneDisk: ClassVar['ReasonForIssue'] = 'hasLinkedCloneDisk'
      unsupportedPMemHAFailOver: ClassVar['ReasonForIssue'] = 'unsupportedPMemHAFailOver'
      unsupportedEncryptedDisk: ClassVar['ReasonForIssue'] = 'unsupportedEncryptedDisk'
      ftMetroClusterNotEditable: ClassVar['ReasonForIssue'] = 'ftMetroClusterNotEditable'
      noHostGroupConfigured: ClassVar['ReasonForIssue'] = 'noHostGroupConfigured'

   reason: Optional[str] = None
   entityName: Optional[str] = None
   entity: Optional[ManagedEntity] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vslm import ID

from pyVmomi.vslm.vso import VStorageObjectResult

class VStorageObjectQueryResult(DynamicData):
   allRecordsReturned: bool
   id: list[ID] = []
   queryResults: list[VStorageObjectResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.vsan import ResourceCheckComponentResult

class ResourceCheckDataPersistenceResult(ResourceCheckComponentResult):
   dataToRebuild: Optional[long] = None
   inaccessibleInstances: list[str] = []
   reducedAvailabilityInstances: list[str] = []
   rebuildInstances: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterHealthResultBase
from pyVmomi.vim.cluster import VsanClusterHealthTest

class VsanClusterHealthGroup(DynamicData):
   groupId: str
   groupName: str
   groupHealth: str
   groupTests: list[VsanClusterHealthTest] = []
   groupDetails: list[VsanClusterHealthResultBase] = []
   inProgress: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import VsanHclComputeResource
from pyVmomi.vim.host import VsanHclControllerInfo
from pyVmomi.vim.host import VsanHclNicInfo

class VsanHostHclInfo(DynamicData):
   hostname: str
   hclChecked: bool
   releaseName: Optional[str] = None
   error: Optional[MethodFault] = None
   controllers: list[VsanHclControllerInfo] = []
   pnics: list[VsanHclNicInfo] = []
   host: Optional[HostSystem] = None
   computeResource: Optional[VsanHclComputeResource] = None
   vsanHostCompatibility: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import EVCMode
from pyVmomi.vim import ExtensibleManagedObject
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import ConnectSpec
from pyVmomi.vim.host import CpuIdInfo
from pyVmomi.vim.host import FeatureCapability
from pyVmomi.vim.host import FeatureMask

from pyVmomi.vim.vm import FeatureRequirement

class EVCManager(ExtensibleManagedObject):
   class EVCState(DynamicData):
      supportedEVCMode: list[EVCMode] = []
      currentEVCModeKey: Optional[str] = None
      guaranteedCPUFeatures: list[CpuIdInfo] = []
      featureCapability: list[FeatureCapability] = []
      featureMask: list[FeatureMask] = []
      featureRequirement: list[FeatureRequirement] = []

   class CheckResult(DynamicData):
      evcModeKey: str
      error: MethodFault
      host: list[HostSystem] = []

   @property
   def managedCluster(self) -> ClusterComputeResource: ...
   @property
   def evcState(self) -> EVCState: ...

   def ConfigureEvc(self, evcModeKey: str, evcGraphicsModeKey: Optional[str]) -> Task: ...
   def DisableEvc(self) -> Task: ...
   def CheckConfigureEvc(self, evcModeKey: str, evcGraphicsModeKey: Optional[str]) -> Task: ...
   def CheckAddHostEvc(self, cnxSpec: ConnectSpec) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedMethod
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import UserSession

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import CertThumbprint

class SessionManager(ManagedObject):
   class LocalTicket(DynamicData):
      userName: str
      passwordFilePath: str

   class GenericServiceTicket(DynamicData):
      class TicketType(Enum):
         HttpNfcServiceTicket: ClassVar['TicketType'] = 'HttpNfcServiceTicket'
         HostServiceTicket: ClassVar['TicketType'] = 'HostServiceTicket'
         VcServiceTicket: ClassVar['TicketType'] = 'VcServiceTicket'

      id: str
      hostName: Optional[str] = None
      sslThumbprint: Optional[str] = None
      certThumbprintList: list[CertThumbprint] = []
      sslCertificate: Optional[str] = None
      ticketType: Optional[str] = None

   class ServiceRequestSpec(DynamicData):
      pass

   class VmomiServiceRequestSpec(ServiceRequestSpec):
      method: ManagedMethod

   class HttpServiceRequestSpec(ServiceRequestSpec):
      class Method(Enum):
         httpOptions: ClassVar['Method'] = 'httpOptions'
         httpGet: ClassVar['Method'] = 'httpGet'
         httpHead: ClassVar['Method'] = 'httpHead'
         httpPost: ClassVar['Method'] = 'httpPost'
         httpPut: ClassVar['Method'] = 'httpPut'
         httpDelete: ClassVar['Method'] = 'httpDelete'
         httpTrace: ClassVar['Method'] = 'httpTrace'
         httpConnect: ClassVar['Method'] = 'httpConnect'

      method: Optional[str] = None
      url: str

   @property
   def sessionList(self) -> list[UserSession]: ...
   @property
   def currentSession(self) -> Optional[UserSession]: ...
   @property
   def message(self) -> Optional[str]: ...
   @property
   def messageLocaleList(self) -> list[str]: ...
   @property
   def supportedLocaleList(self) -> list[str]: ...
   @property
   def defaultLocale(self) -> str: ...

   def UpdateMessage(self, message: str) -> NoReturn: ...
   def LoginByToken(self, locale: Optional[str]) -> UserSession: ...
   def Login(self, userName: str, password: str, locale: Optional[str]) -> UserSession: ...
   def LoginBySSPI(self, base64Token: str, locale: Optional[str]) -> UserSession: ...
   def Logout(self) -> NoReturn: ...
   def AcquireLocalTicket(self, userName: str) -> LocalTicket: ...
   def AcquireGenericServiceTicket(self, spec: ServiceRequestSpec) -> GenericServiceTicket: ...
   def Terminate(self, sessionId: list[str]) -> NoReturn: ...
   def SetLocale(self, locale: str) -> NoReturn: ...
   def LoginExtensionBySubjectName(self, extensionKey: str, locale: Optional[str]) -> UserSession: ...
   def LoginExtensionByCertificate(self, extensionKey: str, locale: Optional[str]) -> UserSession: ...
   def ImpersonateUser(self, userName: str, locale: Optional[str]) -> UserSession: ...
   def SessionIsActive(self, sessionID: str, userName: str) -> bool: ...
   def AcquireCloneTicket(self) -> str: ...
   def CloneSession(self, cloneTicket: str) -> UserSession: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import binary

from pyVmomi.vim.host import AssignableHardwareBinding
from pyVmomi.vim.host import AssignableHardwareConfig

from pyVmomi.vim.vm import DynamicPassthroughInfo
from pyVmomi.vim.vm import VendorDeviceGroupInfo

class AssignableHardwareManager(ManagedObject):
   @property
   def binding(self) -> list[AssignableHardwareBinding]: ...
   @property
   def config(self) -> AssignableHardwareConfig: ...

   def DownloadDescriptionTree(self) -> binary: ...
   def RetrieveDynamicPassthroughInfo(self) -> list[DynamicPassthroughInfo]: ...
   def RetrieveVendorDeviceGroupInfo(self) -> list[VendorDeviceGroupInfo]: ...
   def UpdateConfig(self, config: AssignableHardwareConfig) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VasaStorageArray(DynamicData):
   class DiscoverySvcInfo(DynamicData):
      portType: str
      svcNqn: str
      ipInfo: Optional[DiscoveryIpTransport] = None
      fcInfo: Optional[DiscoveryFcTransport] = None

   class DiscoveryFcTransport(DynamicData):
      nodeWwn: str
      portWwn: str

   class DiscoveryIpTransport(DynamicData):
      ipAddress: str
      portNumber: Optional[str] = None

   name: str
   uuid: str
   vendorId: str
   modelId: str
   discoverySvcInfo: list[DiscoverySvcInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VsanObjectHealth(DynamicData):
   class VsanObjectHealthState(Enum):
      inaccessible: ClassVar['VsanObjectHealthState'] = 'inaccessible'
      reducedavailabilitywithnorebuild: ClassVar['VsanObjectHealthState'] = 'reducedavailabilitywithnorebuild'
      reducedavailabilitywithnorebuilddelaytimer: ClassVar['VsanObjectHealthState'] = 'reducedavailabilitywithnorebuilddelaytimer'
      reducedavailabilitywithactiverebuild: ClassVar['VsanObjectHealthState'] = 'reducedavailabilitywithactiverebuild'
      datamove: ClassVar['VsanObjectHealthState'] = 'datamove'
      nonavailabilityrelatedreconfig: ClassVar['VsanObjectHealthState'] = 'nonavailabilityrelatedreconfig'
      nonavailabilityrelatedincompliance: ClassVar['VsanObjectHealthState'] = 'nonavailabilityrelatedincompliance'
      healthy: ClassVar['VsanObjectHealthState'] = 'healthy'
      reducedavailabilitywithpolicypending: ClassVar['VsanObjectHealthState'] = 'reducedavailabilitywithpolicypending'
      reducedavailabilitywithpolicypendingfailed: ClassVar['VsanObjectHealthState'] = 'reducedavailabilitywithpolicypendingfailed'
      reducedavailabilitywithpausedrebuild: ClassVar['VsanObjectHealthState'] = 'reducedavailabilitywithpausedrebuild'
      nonavailabilityrelatedincompliancewithpolicypending: ClassVar['VsanObjectHealthState'] = 'nonavailabilityrelatedincompliancewithpolicypending'
      nonavailabilityrelatedincompliancewithpolicypendingfailed: ClassVar['VsanObjectHealthState'] = 'nonavailabilityrelatedincompliancewithpolicypendingfailed'
      nonavailabilityrelatedincompliancewithpausedrebuild: ClassVar['VsanObjectHealthState'] = 'nonavailabilityrelatedincompliancewithpausedrebuild'
      remoteAccessible: ClassVar['VsanObjectHealthState'] = 'remoteAccessible'
      VsanObjectHealthState_Unknown: ClassVar['VsanObjectHealthState'] = 'VsanObjectHealthState_Unknown'

   numObjects: int
   health: Optional[str] = None
   objUuids: list[str] = []
   vsanClusterUuid: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.sms.storage.replication import DeviceId
from pyVmomi.sms.storage.replication import GroupOperationResult
from pyVmomi.sms.storage.replication import PointInTimeReplicaId
from pyVmomi.sms.storage.replication import ReplicaId

class FailoverSuccessResult(GroupOperationResult):
   class RecoveredDiskInfo(DynamicData):
      deviceKey: int
      dsUrl: str
      diskPath: str

   class RecoveredDevice(DynamicData):
      targetDeviceId: Optional[ReplicaId] = None
      recoveredDeviceId: Optional[DeviceId] = None
      sourceDeviceId: DeviceId
      info: list[str] = []
      datastore: Datastore
      recoveredDiskInfo: list[RecoveredDiskInfo] = []
      error: Optional[MethodFault] = None
      warnings: list[MethodFault] = []

   newState: str
   pitId: Optional[PointInTimeReplicaId] = None
   pitIdBeforeFailover: Optional[PointInTimeReplicaId] = None
   recoveredDeviceInfo: list[RecoveredDevice] = []
   timeStamp: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DiskPartitionInfo
from pyVmomi.vim.host import VmfsDatastoreSpec

class VmfsDatastoreOption(DynamicData):
   class Info(DynamicData):
      layout: DiskPartitionInfo.Layout
      partitionFormatChange: Optional[bool] = None

   class SingleExtentInfo(Info):
      vmfsExtent: DiskPartitionInfo.BlockRange

   class AllExtentInfo(SingleExtentInfo):
      pass

   class MultipleExtentInfo(Info):
      vmfsExtent: list[DiskPartitionInfo.BlockRange] = []

   info: Info
   spec: VmfsDatastoreSpec



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import StorageComplianceResult

from pyVmomi.vim.host import VsanObjectHealth

class VsanObjectOverallHealth(DynamicData):
   objectHealthDetail: list[VsanObjectHealth] = []
   objectsComplianceDetail: list[StorageComplianceResult] = []
   objectVersionCompliance: Optional[bool] = None
   objectFormatChangeRequiredUuids: list[str] = []
   objectsRelayoutBytes: Optional[long] = None
   globalDedupStoreHealth: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class DesiredSoftwareSpec(DynamicData):
   class BaseImageSpec(DynamicData):
      version: str

   class VendorAddOnSpec(DynamicData):
      name: str
      version: str

   class ComponentSpec(DynamicData):
      name: str
      version: Optional[str] = None

   baseImageSpec: BaseImageSpec
   vendorAddOnSpec: Optional[VendorAddOnSpec] = None
   components: list[ComponentSpec] = []
   removedComponents: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import KeyValue
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import StorageResourceManager
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DatastoreBrowser
from pyVmomi.vim.host import MountInfo

from pyVmomi.vim.storageDrs import StoragePlacementResult

class Datastore(ManagedEntity):
   class Accessible(Enum):
      # Reserved python keyword: commenting out.
      # True: ClassVar['Accessible'] = 'True'
      # Reserved python keyword: commenting out.
      # False: ClassVar['Accessible'] = 'False'
      pass

   class SectorFormat(Enum):
      native_512: ClassVar['SectorFormat'] = 'native_512'
      emulated_512: ClassVar['SectorFormat'] = 'emulated_512'
      native_4k: ClassVar['SectorFormat'] = 'native_4k'

   class Summary(DynamicData):
      class MaintenanceModeState(Enum):
         normal: ClassVar['MaintenanceModeState'] = 'normal'
         enteringMaintenance: ClassVar['MaintenanceModeState'] = 'enteringMaintenance'
         inMaintenance: ClassVar['MaintenanceModeState'] = 'inMaintenance'

      datastore: Optional[Datastore] = None
      name: str
      url: str
      capacity: long
      freeSpace: long
      uncommitted: Optional[long] = None
      accessible: bool
      multipleHostAccess: Optional[bool] = None
      type: str
      maintenanceMode: Optional[str] = None

   class Info(DynamicData):
      name: str
      url: str
      freeSpace: long
      maxFileSize: long
      maxVirtualDiskCapacity: Optional[long] = None
      maxMemoryFileSize: long
      timestamp: Optional[datetime] = None
      containerId: Optional[str] = None
      aliasOf: Optional[str] = None
      supportedVDiskFormats: list[str] = []
      logicalSectorSize: Optional[int] = None
      physicalSectorSize: Optional[int] = None

   class Capability(DynamicData):
      directoryHierarchySupported: bool
      rawDiskMappingsSupported: bool
      perFileThinProvisioningSupported: bool
      storageIORMSupported: bool
      nativeSnapshotSupported: bool
      topLevelDirectoryCreateSupported: Optional[bool] = None
      seSparseSupported: Optional[bool] = None
      vmfsSparseSupported: Optional[bool] = None
      vsanSparseSupported: Optional[bool] = None
      upitSupported: Optional[bool] = None
      vmdkExpandSupported: Optional[bool] = None
      clusteredVmdkSupported: Optional[bool] = None

   class HostMount(DynamicData):
      key: HostSystem
      mountInfo: MountInfo

   class MountPathDatastorePair(DynamicData):
      oldMountPath: str
      datastore: Datastore

   class VVolContainerFailoverPair(DynamicData):
      srcContainer: Optional[str] = None
      tgtContainer: str
      vvolMapping: list[KeyValue] = []

   @property
   def info(self) -> Info: ...
   @property
   def summary(self) -> Summary: ...
   @property
   def host(self) -> list[HostMount]: ...
   @property
   def vm(self) -> list[VirtualMachine]: ...
   @property
   def browser(self) -> DatastoreBrowser: ...
   @property
   def capability(self) -> Capability: ...
   @property
   def iormConfiguration(self) -> Optional[StorageResourceManager.IORMConfigInfo]: ...

   def Refresh(self) -> NoReturn: ...
   def RefreshStorageInfo(self) -> NoReturn: ...
   def UpdateVirtualMachineFiles(self, mountPathDatastoreMapping: list[MountPathDatastorePair]) -> Task: ...
   def RenameDatastore(self, newName: str) -> NoReturn: ...
   def DestroyDatastore(self) -> NoReturn: ...
   def EnterMaintenanceMode(self) -> StoragePlacementResult: ...
   def ExitMaintenanceMode(self) -> Task: ...
   def IsClusteredVmdkEnabled(self) -> bool: ...
   def UpdateVVolVirtualMachineFiles(self, failoverPair: list[VVolContainerFailoverPair]) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.eam import Agent

from pyVmomi.eam.fault import EamFault

class InvalidAgentConfiguration(EamFault):
   invalidAgentConfiguration: Optional[Agent.ConfigInfo] = None
   invalidField: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class UnresolvedVmfsResolutionSpec(DynamicData):
   class VmfsUuidResolution(Enum):
      resignature: ClassVar['VmfsUuidResolution'] = 'resignature'
      forceMount: ClassVar['VmfsUuidResolution'] = 'forceMount'

   extentDevicePath: list[str] = []
   uuidResolution: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.pbm import ExtendedElementDescription

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.capability import TypeInfo

class PropertyMetadata(DynamicData):
   id: str
   summary: ExtendedElementDescription
   mandatory: bool
   type: Optional[TypeInfo] = None
   defaultValue: Optional[object] = None
   allowedValue: Optional[object] = None
   requirementsTypeHint: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class CertThumbprint(DynamicData):
   class HashAlgorithm(Enum):
      sha256: ClassVar['HashAlgorithm'] = 'sha256'

   thumbprint: str
   hashAlgorithm: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.profile import ApplyProfile

from pyVmomi.vim.profile.host import NetworkPolicyProfile

class PortGroupProfile(ApplyProfile):
   class VlanProfile(ApplyProfile):
      pass

   class VirtualSwitchSelectionProfile(ApplyProfile):
      pass

   key: str
   name: str
   vlan: VlanProfile
   vswitch: VirtualSwitchSelectionProfile
   networkPolicy: NetworkPolicyProfile



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.sms import FaultDomainFilter
from pyVmomi.sms import ReplicationGroupFilter

from pyVmomi.vim import Datastore
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

from pyVmomi.sms.provider import Provider
from pyVmomi.sms.provider import ProviderSpec
from pyVmomi.sms.provider import VASAProviderUpgradeSpec

from pyVmomi.sms.storage import BackingStoragePool
from pyVmomi.sms.storage import DatastoreBackingPoolMapping
from pyVmomi.sms.storage import DrsMigrationCapabilityResult
from pyVmomi.sms.storage import StorageArray
from pyVmomi.sms.storage import StorageCapability
from pyVmomi.sms.storage import StorageContainerResult
from pyVmomi.sms.storage import StorageContainerSpec
from pyVmomi.sms.storage import StorageFileSystem
from pyVmomi.sms.storage import StorageLun
from pyVmomi.sms.storage import StoragePort
from pyVmomi.sms.storage import StorageProcessor

from pyVmomi.sms.storage.replication import GroupOperationResult

from pyVmomi.vim.vm.replication import FaultDomainId

class StorageManager(ManagedObject):
   def RegisterProvider(self, providerSpec: ProviderSpec) -> Task: ...
   def UnregisterProvider(self, providerId: str) -> Task: ...
   def QueryProvider(self) -> list[Provider]: ...
   def QueryArray(self, providerId: list[str]) -> list[StorageArray]: ...
   def QueryProcessorAssociatedWithArray(self, arrayId: str) -> list[StorageProcessor]: ...
   def QueryPortAssociatedWithArray(self, arrayId: str) -> list[StoragePort]: ...
   def QueryPortAssociatedWithLun(self, scsi3Id: str, arrayId: str) -> Optional[StoragePort]: ...
   def QueryLunAssociatedWithPort(self, portId: str, arrayId: str) -> list[StorageLun]: ...
   def QueryArrayAssociatedWithLun(self, canonicalName: str) -> Optional[StorageArray]: ...
   def QueryPortAssociatedWithProcessor(self, processorId: str, arrayId: str) -> list[StoragePort]: ...
   def QueryLunAssociatedWithArray(self, arrayId: str) -> list[StorageLun]: ...
   def QueryFileSystemAssociatedWithArray(self, arrayId: str) -> list[StorageFileSystem]: ...
   def QueryDatastoreCapability(self, datastore: Datastore) -> Optional[StorageCapability]: ...
   def QueryHostAssociatedWithLun(self, scsi3Id: str, arrayId: str) -> list[HostSystem]: ...
   def QueryVmfsDatastoreAssociatedWithLun(self, scsi3Id: str, arrayId: str) -> Optional[Datastore]: ...
   def QueryNfsDatastoreAssociatedWithFileSystem(self, fileSystemId: str, arrayId: str) -> Optional[Datastore]: ...
   def QueryDrsMigrationCapabilityForPerformance(self, srcDatastore: Datastore, dstDatastore: Datastore) -> bool: ...
   def QueryDrsMigrationCapabilityForPerformanceEx(self, datastore: list[Datastore]) -> DrsMigrationCapabilityResult: ...
   def QueryStorageContainer(self, containerSpec: Optional[StorageContainerSpec]) -> Optional[StorageContainerResult]: ...
   def QueryAssociatedBackingStoragePool(self, entityId: Optional[str], entityType: Optional[str]) -> list[BackingStoragePool]: ...
   def QueryDatastoreBackingPoolMapping(self, datastore: list[Datastore]) -> list[DatastoreBackingPoolMapping]: ...
   def RefreshCACertificatesAndCRLs(self, providerId: list[str]) -> Task: ...
   def QueryFaultDomain(self, filter: Optional[FaultDomainFilter]) -> list[FaultDomainId]: ...
   def QueryReplicationGroupInfo(self, rgFilter: ReplicationGroupFilter) -> list[GroupOperationResult]: ...
   def UpgradeVASAProvider(self, upgradeSpec: VASAProviderUpgradeSpec) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class VsanKmsHealth(DynamicData):
   serverName: str
   health: str
   error: Optional[MethodFault] = None
   trustHealth: Optional[str] = None
   certHealth: Optional[str] = None
   certExpireDate: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import MigrationFault

class AffinityConfigured(MigrationFault):
   class Affinity(Enum):
      memory: ClassVar['Affinity'] = 'memory'
      cpu: ClassVar['Affinity'] = 'cpu'

   configuredAffinity: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.device import VirtualVmxnet

class VirtualVmxnet3(VirtualVmxnet):
   class StrictLatencyConfig(DynamicData):
      class DisableOffload(Enum):
         NONE: ClassVar['DisableOffload'] = 'NONE'
         TSO: ClassVar['DisableOffload'] = 'TSO'
         LRO: ClassVar['DisableOffload'] = 'LRO'
         TSO_LRO: ClassVar['DisableOffload'] = 'TSO_LRO'

      allowed: Optional[bool] = None
      measureLatency: Optional[bool] = None
      maxTxQueues: Optional[int] = None
      maxRxQueues: Optional[int] = None
      txDataRingDescSize: Optional[int] = None
      rxDataRingDescSize: Optional[int] = None
      disableOffload: Optional[str] = None

   uptv2Enabled: Optional[bool] = None
   strictLatencyConfig: Optional[StrictLatencyConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DateTimeSystem
from pyVmomi.vim.host import NtpConfig
from pyVmomi.vim.host import PtpConfig

class DateTimeInfo(DynamicData):
   class Protocol(Enum):
      ntp: ClassVar['Protocol'] = 'ntp'
      ptp: ClassVar['Protocol'] = 'ptp'

   timeZone: DateTimeSystem.TimeZone
   systemClockProtocol: Optional[str] = None
   ntpConfig: Optional[NtpConfig] = None
   ptpConfig: Optional[PtpConfig] = None
   enabled: Optional[bool] = None
   disableEvents: Optional[bool] = None
   disableFallback: Optional[bool] = None
   inFallbackState: Optional[bool] = None
   serviceSync: Optional[bool] = None
   lastSyncTime: Optional[datetime] = None
   remoteNtpServer: Optional[str] = None
   ntpRunTime: Optional[long] = None
   ptpRunTime: Optional[long] = None
   ntpDuration: Optional[str] = None
   ptpDuration: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from . import provider as provider
from . import types as types

from .CapabilityInstance import CapabilityInstance as CapabilityInstance
from .CapabilityMetadata import CapabilityMetadata as CapabilityMetadata
from .CapabilityMetadataManager import CapabilityMetadataManager as CapabilityMetadataManager
from .ConstraintInstance import ConstraintInstance as ConstraintInstance
from .GenericTypeInfo import GenericTypeInfo as GenericTypeInfo
from .Operator import Operator as Operator
from .PropertyInstance import PropertyInstance as PropertyInstance
from .PropertyMetadata import PropertyMetadata as PropertyMetadata
from .TypeInfo import TypeInfo as TypeInfo



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VasaStorageArray

from pyVmomi.vmodl import DynamicData

class StorageArray(DynamicData):
   class BlockDeviceInterface(Enum):
      fc: ClassVar['BlockDeviceInterface'] = 'fc'
      iscsi: ClassVar['BlockDeviceInterface'] = 'iscsi'
      fcoe: ClassVar['BlockDeviceInterface'] = 'fcoe'
      otherBlock: ClassVar['BlockDeviceInterface'] = 'otherBlock'

   class FileSystemInterface(Enum):
      nfs: ClassVar['FileSystemInterface'] = 'nfs'
      otherFileSystem: ClassVar['FileSystemInterface'] = 'otherFileSystem'

   class VasaProfile(Enum):
      blockDevice: ClassVar['VasaProfile'] = 'blockDevice'
      fileSystem: ClassVar['VasaProfile'] = 'fileSystem'
      capability: ClassVar['VasaProfile'] = 'capability'
      policy: ClassVar['VasaProfile'] = 'policy'
      object: ClassVar['VasaProfile'] = 'object'
      statistics: ClassVar['VasaProfile'] = 'statistics'
      storageDrsBlockDevice: ClassVar['VasaProfile'] = 'storageDrsBlockDevice'
      storageDrsFileSystem: ClassVar['VasaProfile'] = 'storageDrsFileSystem'

   name: str
   uuid: str
   vendorId: str
   modelId: str
   firmware: Optional[str] = None
   alternateName: list[str] = []
   supportedBlockInterface: list[str] = []
   supportedFileSystemInterface: list[str] = []
   supportedProfile: list[str] = []
   priority: Optional[int] = None
   discoverySvc: list[VasaStorageArray.DiscoverySvcInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class ServiceLocator(DynamicData):
   class Credential(DynamicData):
      pass

   class NamePassword(Credential):
      username: str
      password: str

   class SAMLCredential(Credential):
      token: Optional[str] = None

   instanceUuid: str
   url: str
   credential: Credential
   sslThumbprint: Optional[str] = None
   sslCertificate: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore
from pyVmomi.vim import Folder
from pyVmomi.vim import HttpNfcLease
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import Network
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import CloneSpec
from pyVmomi.vim.vApp import ProductInfo
from pyVmomi.vim.vApp import VAppConfigInfo
from pyVmomi.vim.vApp import VAppConfigSpec

class VirtualApp(ResourcePool):
   class VAppState(Enum):
      started: ClassVar['VAppState'] = 'started'
      stopped: ClassVar['VAppState'] = 'stopped'
      starting: ClassVar['VAppState'] = 'starting'
      stopping: ClassVar['VAppState'] = 'stopping'

   class Summary(ResourcePool.Summary):
      product: Optional[ProductInfo] = None
      vAppState: Optional[VAppState] = None
      suspended: Optional[bool] = None
      installBootRequired: Optional[bool] = None
      instanceUuid: Optional[str] = None

   class LinkInfo(DynamicData):
      key: ManagedEntity
      destroyWithParent: Optional[bool] = None

   @property
   def parentFolder(self) -> Optional[Folder]: ...
   @property
   def datastore(self) -> list[Datastore]: ...
   @property
   def network(self) -> list[Network]: ...
   @property
   def vAppConfig(self) -> Optional[VAppConfigInfo]: ...
   @property
   def parentVApp(self) -> Optional[ManagedEntity]: ...
   @property
   def childLink(self) -> list[LinkInfo]: ...

   def UpdateVAppConfig(self, spec: VAppConfigSpec) -> NoReturn: ...
   def UpdateLinkedChildren(self, addChangeSet: list[LinkInfo], removeSet: list[ManagedEntity]) -> NoReturn: ...
   def Clone(self, name: str, target: ResourcePool, spec: CloneSpec) -> Task: ...
   def ExportVApp(self) -> HttpNfcLease: ...
   def PowerOn(self) -> Task: ...
   def PowerOff(self, force: bool) -> Task: ...
   def Suspend(self) -> Task: ...
   def Unregister(self) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VipDVswitchConfig
from pyVmomi.vim.vsan import VipNetworkConfig
from pyVmomi.vim.vsan import VipVswitchConfig

class VipConfigSpec(DynamicData):
   enabled: Optional[bool] = None
   v4NetworkConfig: Optional[VipNetworkConfig] = None
   v6NetworkConfig: Optional[VipNetworkConfig] = None
   vswitchConfig: Optional[VipVswitchConfig] = None
   distributedSwitchConfig: Optional[VipDVswitchConfig] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore

from pyVmomi.vim.vm import TargetInfo

class DatastoreInfo(TargetInfo):
   datastore: Datastore.Summary
   capability: Datastore.Capability
   maxFileSize: long
   maxVirtualDiskCapacity: Optional[long] = None
   maxPhysicalRDMFileSize: Optional[long] = None
   maxVirtualRDMFileSize: Optional[long] = None
   mode: str
   vStorageSupport: Optional[str] = None
   supportedVDiskFormats: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class InfraUpdateHaConfigInfo(DynamicData):
   class BehaviorType(Enum):
      Manual: ClassVar['BehaviorType'] = 'Manual'
      Automated: ClassVar['BehaviorType'] = 'Automated'

   class RemediationType(Enum):
      QuarantineMode: ClassVar['RemediationType'] = 'QuarantineMode'
      MaintenanceMode: ClassVar['RemediationType'] = 'MaintenanceMode'

   enabled: Optional[bool] = None
   behavior: Optional[str] = None
   moderateRemediation: Optional[str] = None
   severeRemediation: Optional[str] = None
   providers: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class SevInfo(DynamicData):
   class SevState(Enum):
      uninitialized: ClassVar['SevState'] = 'uninitialized'
      initialized: ClassVar['SevState'] = 'initialized'
      working: ClassVar['SevState'] = 'working'

   sevState: str
   maxSevEsGuests: long
   snpState: Optional[str] = None
   snpSupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanSpaceEfficiencyMetadataSize

class VsanLimitHealthResult(DynamicData):
   hostname: Optional[str] = None
   issueFound: bool
   maxComponents: int
   freeComponents: int
   componentLimitHealth: str
   lowestFreeDiskSpacePct: int
   usedDiskSpaceB: long
   totalDiskSpaceB: long
   diskFreeSpaceHealth: str
   reservedRcSizeB: long
   totalRcSizeB: long
   rcFreeReservationHealth: str
   totalLogicalSpaceB: Optional[long] = None
   logicalSpaceUsedB: Optional[long] = None
   dedupMetadataSizeB: Optional[long] = None
   diskTransientCapacityUsedB: Optional[long] = None
   dgTransientCapacityUsedB: Optional[long] = None
   slackSpaceCapRequired: Optional[long] = None
   resyncPauseThreshold: Optional[long] = None
   spaceEfficiencyMetadataSizeB: Optional[VsanSpaceEfficiencyMetadataSize] = None
   hostRebuildCapacity: Optional[long] = None
   minSpaceRequiredForVsanOp: Optional[long] = None
   enforceCapResrvSpace: Optional[long] = None
   cdReservedSizeB: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import RuntimeFault

class DisallowedChangeByService(RuntimeFault):
   class DisallowedChange(Enum):
      hotExtendDisk: ClassVar['DisallowedChange'] = 'hotExtendDisk'

   serviceName: str
   disallowedChange: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import byte

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import Device

class ScsiLun(Device):
   class ScsiLunType(Enum):
      disk: ClassVar['ScsiLunType'] = 'disk'
      tape: ClassVar['ScsiLunType'] = 'tape'
      printer: ClassVar['ScsiLunType'] = 'printer'
      processor: ClassVar['ScsiLunType'] = 'processor'
      worm: ClassVar['ScsiLunType'] = 'worm'
      cdrom: ClassVar['ScsiLunType'] = 'cdrom'
      scanner: ClassVar['ScsiLunType'] = 'scanner'
      opticalDevice: ClassVar['ScsiLunType'] = 'opticalDevice'
      mediaChanger: ClassVar['ScsiLunType'] = 'mediaChanger'
      communications: ClassVar['ScsiLunType'] = 'communications'
      storageArrayController: ClassVar['ScsiLunType'] = 'storageArrayController'
      enclosure: ClassVar['ScsiLunType'] = 'enclosure'
      unknown: ClassVar['ScsiLunType'] = 'unknown'

   class DeviceProtocol(Enum):
      NVMe: ClassVar['DeviceProtocol'] = 'NVMe'
      SCSI: ClassVar['DeviceProtocol'] = 'SCSI'

   class Capabilities(DynamicData):
      updateDisplayNameSupported: bool

   class DurableName(DynamicData):
      namespace: str
      namespaceId: byte
      data: list[byte] = []

   class State(Enum):
      unknownState: ClassVar['State'] = 'unknownState'
      ok: ClassVar['State'] = 'ok'
      error: ClassVar['State'] = 'error'
      off: ClassVar['State'] = 'off'
      quiesced: ClassVar['State'] = 'quiesced'
      degraded: ClassVar['State'] = 'degraded'
      lostCommunication: ClassVar['State'] = 'lostCommunication'
      timeout: ClassVar['State'] = 'timeout'

   class DescriptorQuality(Enum):
      highQuality: ClassVar['DescriptorQuality'] = 'highQuality'
      mediumQuality: ClassVar['DescriptorQuality'] = 'mediumQuality'
      lowQuality: ClassVar['DescriptorQuality'] = 'lowQuality'
      unknownQuality: ClassVar['DescriptorQuality'] = 'unknownQuality'

   class Descriptor(DynamicData):
      quality: str
      id: str

   class VStorageSupportStatus(Enum):
      vStorageSupported: ClassVar['VStorageSupportStatus'] = 'vStorageSupported'
      vStorageUnsupported: ClassVar['VStorageSupportStatus'] = 'vStorageUnsupported'
      vStorageUnknown: ClassVar['VStorageSupportStatus'] = 'vStorageUnknown'

   class LunReservationStatus(Enum):
      LUN_RESERVED_UNKNOWN: ClassVar['LunReservationStatus'] = 'LUN_RESERVED_UNKNOWN'
      LUN_RESERVED_YES: ClassVar['LunReservationStatus'] = 'LUN_RESERVED_YES'
      LUN_RESERVED_NO: ClassVar['LunReservationStatus'] = 'LUN_RESERVED_NO'
      LUN_RESERVED_NOT_SUPPORTED: ClassVar['LunReservationStatus'] = 'LUN_RESERVED_NOT_SUPPORTED'

   key: Optional[str] = None
   uuid: str
   descriptor: list[Descriptor] = []
   canonicalName: Optional[str] = None
   displayName: Optional[str] = None
   lunType: str
   vendor: Optional[str] = None
   model: Optional[str] = None
   revision: Optional[str] = None
   scsiLevel: Optional[int] = None
   serialNumber: Optional[str] = None
   durableName: Optional[DurableName] = None
   alternateName: list[DurableName] = []
   standardInquiry: list[byte] = []
   queueDepth: Optional[int] = None
   operationalState: list[str] = []
   capabilities: Optional[Capabilities] = None
   vStorageSupport: Optional[str] = None
   protocolEndpoint: Optional[bool] = None
   perenniallyReserved: Optional[bool] = None
   clusteredVmdkSupported: Optional[bool] = None
   applicationProtocol: Optional[str] = None
   dispersedNs: Optional[bool] = None
   deviceReservation: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.host import NvmeSpec

class NvmeConnectSpec(NvmeSpec):
   subnqn: str
   controllerId: Optional[int] = None
   adminQueueSize: Optional[int] = None
   keepAliveTimeout: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanClusterHealthTest

class VsanClusterProactiveTestResult(DynamicData):
   overallStatus: str
   overallStatusDescription: str
   timestamp: datetime
   healthTest: Optional[VsanClusterHealthTest] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.option import OptionValue

from pyVmomi.vim.vm import RelocateSpec

class InstantCloneSpec(DynamicData):
   name: str
   location: RelocateSpec
   config: list[OptionValue] = []
   biosUuid: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import HostSystem
from pyVmomi.vim import Task

class VsanClusterMgmtInternalSystem(ManagedObject):
   def RemediateVsanCluster(self, cluster: ClusterComputeResource) -> Task: ...
   def RemediateVsanHost(self, host: HostSystem) -> Task: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import VmConfigFault

class NumVirtualCpusIncompatible(VmConfigFault):
   class Reason(Enum):
      recordReplay: ClassVar['Reason'] = 'recordReplay'
      faultTolerance: ClassVar['Reason'] = 'faultTolerance'

   reason: str
   numCpu: int



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

class VsanPerfQuerySpec(DynamicData):
   entityRefId: str
   startTime: Optional[datetime] = None
   endTime: Optional[datetime] = None
   group: Optional[str] = None
   labels: list[str] = []
   interval: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vim import Description
from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.ext import ExtendedProductInfo
from pyVmomi.vim.ext import ManagedEntityInfo
from pyVmomi.vim.ext import SolutionManagerInfo

class Extension(DynamicData):
   class ServerInfo(DynamicData):
      url: str
      description: Description
      company: str
      type: str
      adminEmail: list[str] = []
      serverThumbprint: Optional[str] = None
      serverCertificate: Optional[str] = None

   class ClientInfo(DynamicData):
      version: str
      description: Description
      company: str
      type: str
      url: str

   class TaskTypeInfo(DynamicData):
      taskID: str

   class EventTypeInfo(DynamicData):
      eventID: str
      eventTypeSchema: Optional[str] = None

   class FaultTypeInfo(DynamicData):
      faultID: str

   class PrivilegeInfo(DynamicData):
      privID: str
      privGroupName: str

   class ResourceInfo(DynamicData):
      locale: str
      module: str
      data: list[KeyValue] = []

   class HealthInfo(DynamicData):
      url: str

   class OvfConsumerInfo(DynamicData):
      callbackUrl: str
      sectionType: list[str] = []

   description: Description
   key: str
   company: Optional[str] = None
   type: Optional[str] = None
   version: str
   subjectName: Optional[str] = None
   server: list[ServerInfo] = []
   client: list[ClientInfo] = []
   taskList: list[TaskTypeInfo] = []
   eventList: list[EventTypeInfo] = []
   faultList: list[FaultTypeInfo] = []
   privilegeList: list[PrivilegeInfo] = []
   resourceList: list[ResourceInfo] = []
   lastHeartbeatTime: datetime
   healthInfo: Optional[HealthInfo] = None
   ovfConsumerInfo: Optional[OvfConsumerInfo] = None
   extendedProductInfo: Optional[ExtendedProductInfo] = None
   managedEntityInfo: list[ManagedEntityInfo] = []
   shownInSolutionManager: Optional[bool] = None
   solutionManagerInfo: Optional[SolutionManagerInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

class CertificateManager(ManagedObject):
   class CertificateKind(Enum):
      Machine: ClassVar['CertificateKind'] = 'Machine'
      VASAClient: ClassVar['CertificateKind'] = 'VASAClient'

   class CertificateSpec(DynamicData):
      kind: str
      subjectAlternativeNames: list[str] = []

   class CertificateInfo(DynamicData):
      class CertificateStatus(Enum):
         unknown: ClassVar['CertificateStatus'] = 'unknown'
         expired: ClassVar['CertificateStatus'] = 'expired'
         expiring: ClassVar['CertificateStatus'] = 'expiring'
         expiringShortly: ClassVar['CertificateStatus'] = 'expiringShortly'
         expirationImminent: ClassVar['CertificateStatus'] = 'expirationImminent'
         good: ClassVar['CertificateStatus'] = 'good'

      kind: Optional[str] = None
      issuer: Optional[str] = None
      notBefore: Optional[datetime] = None
      notAfter: Optional[datetime] = None
      subject: Optional[str] = None
      status: str

   @property
   def certificateInfo(self) -> CertificateInfo: ...

   def RetrieveCertificateInfoList(self) -> list[CertificateInfo]: ...
   def GenerateCertificateSigningRequest(self, useIpAddressAsCommonName: bool, spec: Optional[CertificateSpec]) -> str: ...
   def GenerateCertificateSigningRequestByDn(self, distinguishedName: str, spec: Optional[CertificateSpec]) -> str: ...
   def ProvisionServerPrivateKey(self, key: str) -> NoReturn: ...
   def InstallServerCertificate(self, cert: str) -> NoReturn: ...
   def ReplaceCACertificatesAndCRLs(self, caCert: list[str], caCrl: list[str]) -> NoReturn: ...
   def NotifyAffectedServices(self, services: list[str]) -> NoReturn: ...
   def ListCACertificates(self) -> list[str]: ...
   def ListCACertificateRevocationLists(self) -> list[str]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class StorageContainer(DynamicData):
   class VvolContainerTypeEnum(Enum):
      NFS: ClassVar['VvolContainerTypeEnum'] = 'NFS'
      NFS4x: ClassVar['VvolContainerTypeEnum'] = 'NFS4x'
      SCSI: ClassVar['VvolContainerTypeEnum'] = 'SCSI'
      NVMe: ClassVar['VvolContainerTypeEnum'] = 'NVMe'

   uuid: str
   name: str
   maxVvolSizeInMB: long
   providerId: list[str] = []
   arrayId: list[str] = []
   vvolContainerType: Optional[str] = None
   stretched: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.vm.customization import Options

class WinOptions(Options):
   class SysprepRebootOption(Enum):
      reboot: ClassVar['SysprepRebootOption'] = 'reboot'
      noreboot: ClassVar['SysprepRebootOption'] = 'noreboot'
      shutdown: ClassVar['SysprepRebootOption'] = 'shutdown'

   changeSID: bool
   deleteAccounts: bool
   reboot: Optional[SysprepRebootOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class VsanIscsiLUNCommonInfo(DynamicData):
   class VsanIscsiLUNStatus(Enum):
      Online: ClassVar['VsanIscsiLUNStatus'] = 'Online'
      Offline: ClassVar['VsanIscsiLUNStatus'] = 'Offline'
      VsanIscsiLUNStatus_Unknown: ClassVar['VsanIscsiLUNStatus'] = 'VsanIscsiLUNStatus_Unknown'

   lunId: Optional[int] = None
   alias: Optional[str] = None
   lunSize: long
   status: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import BootDeviceInfo

class BootDeviceSystem(ManagedObject):
   class BootDevice(DynamicData):
      key: str
      description: str

   def QueryBootDevices(self) -> Optional[BootDeviceInfo]: ...
   def UpdateBootDevice(self, key: str) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VirtualMachine

from pyVmomi.vim.fault import VmFaultToleranceIssue

class NotSupportedDeviceForFT(VmFaultToleranceIssue):
   class DeviceType(Enum):
      virtualVmxnet3: ClassVar['DeviceType'] = 'virtualVmxnet3'
      paraVirtualSCSIController: ClassVar['DeviceType'] = 'paraVirtualSCSIController'

   host: HostSystem
   hostName: Optional[str] = None
   vm: VirtualMachine
   vmName: Optional[str] = None
   deviceType: str
   deviceLabel: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.fault import ProfileUpdateFailed

from pyVmomi.vim.profile import ComplianceLocator
from pyVmomi.vim.profile import ComplianceProfile
from pyVmomi.vim.profile import DeferredPolicyOptionParameter
from pyVmomi.vim.profile import Profile

from pyVmomi.vim.profile.host import ExecuteResult
from pyVmomi.vim.profile.host import HostApplyProfile

class HostProfile(Profile):
   class ConfigInfo(Profile.ConfigInfo):
      applyProfile: Optional[HostApplyProfile] = None
      defaultComplyProfile: Optional[ComplianceProfile] = None
      defaultComplyLocator: list[ComplianceLocator] = []
      customComplyProfile: Optional[ComplianceProfile] = None
      disabledExpressionList: list[str] = []
      description: Optional[Profile.Description] = None

   class ConfigSpec(Profile.CreateSpec):
      pass

   class SerializedHostProfileSpec(Profile.SerializedCreateSpec):
      validatorHost: Optional[HostSystem] = None
      validating: Optional[bool] = None

   class CompleteConfigSpec(ConfigSpec):
      applyProfile: Optional[HostApplyProfile] = None
      customComplyProfile: Optional[ComplianceProfile] = None
      disabledExpressionListChanged: bool
      disabledExpressionList: list[str] = []
      validatorHost: Optional[HostSystem] = None
      validating: Optional[bool] = None
      hostConfig: Optional[ConfigInfo] = None

   class HostBasedConfigSpec(ConfigSpec):
      host: HostSystem
      useHostProfileEngine: Optional[bool] = None

   class ValidationState(Enum):
      Ready: ClassVar['ValidationState'] = 'Ready'
      Running: ClassVar['ValidationState'] = 'Running'
      Failed: ClassVar['ValidationState'] = 'Failed'

   class ValidationFailureInfo(DynamicData):
      class UpdateType(Enum):
         HostBased: ClassVar['UpdateType'] = 'HostBased'
         Import: ClassVar['UpdateType'] = 'Import'
         Edit: ClassVar['UpdateType'] = 'Edit'
         Compose: ClassVar['UpdateType'] = 'Compose'

      name: str
      annotation: str
      updateType: str
      host: Optional[HostSystem] = None
      applyProfile: Optional[HostApplyProfile] = None
      failures: list[ProfileUpdateFailed.UpdateFailure] = []
      faults: list[MethodFault] = []

   @property
   def validationState(self) -> Optional[str]: ...
   @property
   def validationStateUpdateTime(self) -> Optional[datetime]: ...
   @property
   def validationFailureInfo(self) -> Optional[ValidationFailureInfo]: ...
   @property
   def complianceCheckTime(self) -> Optional[datetime]: ...
   @property
   def referenceHost(self) -> Optional[HostSystem]: ...

   def ResetValidationState(self) -> NoReturn: ...
   def UpdateReferenceHost(self, host: Optional[HostSystem]) -> NoReturn: ...
   def Update(self, config: ConfigSpec) -> NoReturn: ...
   def Execute(self, host: HostSystem, deferredParam: list[DeferredPolicyOptionParameter]) -> ExecuteResult: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Task

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VffsVolume

from pyVmomi.vim.option import ChoiceOption
from pyVmomi.vim.option import LongOption

from pyVmomi.vim.vm.device import VirtualDisk

class VFlashManager(ManagedObject):
   class VFlashResourceConfigSpec(DynamicData):
      vffsUuid: str

   class VFlashResourceConfigInfo(DynamicData):
      vffs: Optional[VffsVolume] = None
      capacity: long

   class VFlashResourceRunTimeInfo(DynamicData):
      usage: long
      capacity: long
      accessible: bool
      capacityForVmCache: long
      freeForVmCache: long

   class VFlashCacheConfigSpec(DynamicData):
      defaultVFlashModule: str
      swapCacheReservationInGB: long

   class VFlashCacheConfigInfo(DynamicData):
      class VFlashModuleConfigOption(DynamicData):
         vFlashModule: str
         vFlashModuleVersion: str
         minSupportedModuleVersion: str
         cacheConsistencyType: ChoiceOption
         cacheMode: ChoiceOption
         blockSizeInKBOption: LongOption
         reservationInMBOption: LongOption
         maxDiskSizeInKB: long

      vFlashModuleConfigOption: list[VFlashModuleConfigOption] = []
      defaultVFlashModule: Optional[str] = None
      swapCacheReservationInGB: Optional[long] = None

   class VFlashConfigInfo(DynamicData):
      vFlashResourceConfigInfo: Optional[VFlashResourceConfigInfo] = None
      vFlashCacheConfigInfo: Optional[VFlashCacheConfigInfo] = None

   @property
   def vFlashConfigInfo(self) -> Optional[VFlashConfigInfo]: ...

   def ConfigureVFlashResourceEx(self, devicePath: list[str]) -> Task: ...
   def ConfigureVFlashResource(self, spec: VFlashResourceConfigSpec) -> NoReturn: ...
   def RemoveVFlashResource(self) -> NoReturn: ...
   def ConfigureHostVFlashCache(self, spec: VFlashCacheConfigSpec) -> NoReturn: ...
   def GetVFlashModuleDefaultConfig(self, vFlashModule: str) -> VirtualDisk.VFlashCacheConfigInfo: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import PlacementSpec

from pyVmomi.vim.storageDrs import PlacementAffinityRule
from pyVmomi.vim.storageDrs import PlacementRankVmSpec

class PlacementRankSpec(DynamicData):
   specs: list[PlacementSpec] = []
   clusters: list[ClusterComputeResource] = []
   rules: list[PlacementAffinityRule] = []
   placementRankByVm: list[PlacementRankVmSpec] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import Snapshot

class FileLayout(DynamicData):
   class DiskLayout(DynamicData):
      key: int
      diskFile: list[str] = []

   class SnapshotLayout(DynamicData):
      key: Snapshot
      snapshotFile: list[str] = []

   configFile: list[str] = []
   logFile: list[str] = []
   disk: list[DiskLayout] = []
   snapshot: list[SnapshotLayout] = []
   swapFile: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.sms.storage.replication import GroupOperationResult

class QueryPointInTimeReplicaSummaryResult(GroupOperationResult):
   class ReplicaIntervalQueryResult(DynamicData):
      fromDate: datetime
      toDate: datetime
      number: int

   intervalResults: list[ReplicaIntervalQueryResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import HostSystem
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasFdmHostState

from pyVmomi.vim.encryption import CryptoKeyId

from pyVmomi.vim.host import HealthStatusSystem
from pyVmomi.vim.host import PartialMaintenanceModeRuntimeInfo
from pyVmomi.vim.host import TpmDigestInfo
from pyVmomi.vim.host import VFlashManager

from pyVmomi.vim.vsan.host import VsanRuntimeInfo

class RuntimeInfo(DynamicData):
   class NetStackInstanceRuntimeInfo(DynamicData):
      class State(Enum):
         inactive: ClassVar['State'] = 'inactive'
         active: ClassVar['State'] = 'active'
         deactivating: ClassVar['State'] = 'deactivating'
         activating: ClassVar['State'] = 'activating'

      netStackInstanceKey: str
      state: Optional[str] = None
      vmknicKeys: list[str] = []
      maxNumberOfConnections: Optional[int] = None
      currentIpV6Enabled: Optional[bool] = None

   class PlacedVirtualNicIdentifier(DynamicData):
      vm: VirtualMachine
      vnicKey: str
      reservation: Optional[int] = None

   class PnicNetworkResourceInfo(DynamicData):
      pnicDevice: str
      availableBandwidthForVMTraffic: Optional[long] = None
      unusedBandwidthForVMTraffic: Optional[long] = None
      placedVirtualNics: list[PlacedVirtualNicIdentifier] = []

   class NetworkResourceRuntimeInfo(DynamicData):
      pnicResourceInfo: list[PnicNetworkResourceInfo] = []

   class NetworkRuntimeInfo(DynamicData):
      netStackInstanceRuntimeInfo: list[NetStackInstanceRuntimeInfo] = []
      networkResourceRuntime: Optional[NetworkResourceRuntimeInfo] = None

   class StatelessNvdsMigrationState(Enum):
      ready: ClassVar['StatelessNvdsMigrationState'] = 'ready'
      notNeeded: ClassVar['StatelessNvdsMigrationState'] = 'notNeeded'
      unknown: ClassVar['StatelessNvdsMigrationState'] = 'unknown'

   class StateEncryptionInfo(DynamicData):
      class ProtectionMode(Enum):
         none: ClassVar['ProtectionMode'] = 'none'
         tpm: ClassVar['ProtectionMode'] = 'tpm'

      protectionMode: str
      requireSecureBoot: Optional[bool] = None
      requireExecInstalledOnly: Optional[bool] = None

   connectionState: HostSystem.ConnectionState
   powerState: HostSystem.PowerState
   standbyMode: Optional[str] = None
   inMaintenanceMode: bool
   inQuarantineMode: Optional[bool] = None
   bootTime: Optional[datetime] = None
   healthSystemRuntime: Optional[HealthStatusSystem.Runtime] = None
   dasHostState: Optional[DasFdmHostState] = None
   tpmPcrValues: list[TpmDigestInfo] = []
   vsanRuntimeInfo: Optional[VsanRuntimeInfo] = None
   networkRuntimeInfo: Optional[NetworkRuntimeInfo] = None
   vFlashResourceRuntimeInfo: Optional[VFlashManager.VFlashResourceRunTimeInfo] = None
   hostMaxVirtualDiskCapacity: Optional[long] = None
   cryptoState: Optional[str] = None
   cryptoKeyId: Optional[CryptoKeyId] = None
   statelessNvdsMigrationReady: Optional[str] = None
   partialMaintenanceMode: list[PartialMaintenanceModeRuntimeInfo] = []
   stateEncryption: Optional[StateEncryptionInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.profile import DeferredPolicyOptionParameter

class AnswerFile(DynamicData):
   userInput: list[DeferredPolicyOptionParameter] = []
   createdTime: datetime
   modifiedTime: datetime



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.scheduler import MonthlyTaskScheduler

class MonthlyByWeekdayTaskScheduler(MonthlyTaskScheduler):
   class DayOfWeek(Enum):
      sunday: ClassVar['DayOfWeek'] = 'sunday'
      monday: ClassVar['DayOfWeek'] = 'monday'
      tuesday: ClassVar['DayOfWeek'] = 'tuesday'
      wednesday: ClassVar['DayOfWeek'] = 'wednesday'
      thursday: ClassVar['DayOfWeek'] = 'thursday'
      friday: ClassVar['DayOfWeek'] = 'friday'
      saturday: ClassVar['DayOfWeek'] = 'saturday'

   class WeekOfMonth(Enum):
      first: ClassVar['WeekOfMonth'] = 'first'
      second: ClassVar['WeekOfMonth'] = 'second'
      third: ClassVar['WeekOfMonth'] = 'third'
      fourth: ClassVar['WeekOfMonth'] = 'fourth'
      last: ClassVar['WeekOfMonth'] = 'last'

   offset: WeekOfMonth
   weekday: DayOfWeek



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.profile import Profile

class ComplianceResult(DynamicData):
   class Status(Enum):
      compliant: ClassVar['Status'] = 'compliant'
      nonCompliant: ClassVar['Status'] = 'nonCompliant'
      unknown: ClassVar['Status'] = 'unknown'
      running: ClassVar['Status'] = 'running'

   class ComplianceFailure(DynamicData):
      class ComplianceFailureValues(DynamicData):
         comparisonIdentifier: str
         profileInstance: Optional[str] = None
         hostValue: Optional[object] = None
         profileValue: Optional[object] = None

      failureType: str
      message: LocalizableMessage
      expressionName: Optional[str] = None
      failureValues: list[ComplianceFailureValues] = []

   profile: Optional[Profile] = None
   complianceStatus: str
   entity: Optional[ManagedEntity] = None
   checkTime: Optional[datetime] = None
   failure: list[ComplianceFailure] = []
